@@ -209,6 +209,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def PayOffer(self, request, context):
         return self.handler.handle_pay_offer(request)
 
+    def DecryptSqueak(self, request, context):
+        return self.handler.handle_decrypt_squeak(request)
+
     def GetSentPayments(self, request, context):
         return self.handler.handle_get_sent_payments(request)
 
@@ -386,12 +389,6 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetSellPrice(self, request, context):
         return self.handler.handle_get_sell_price(request)
 
-    def SetTwitterBearerToken(self, request, context):
-        return self.handler.handle_set_twitter_bearer_token(request)
-
-    def GetTwitterBearerToken(self, request, context):
-        return self.handler.handle_get_twitter_bearer_token(request)
-
     def AddTwitterAccount(self, request, context):
         return self.handler.handle_add_twitter_account(request)
 
@@ -400,6 +397,3 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
 
     def DeleteTwitterAccount(self, request, context):
         return self.handler.handle_delete_twitter_account(request)
-
-    def GetTwitterStreamStatus(self, request, context):
-        return self.handler.handle_get_twitter_stream_status(request)
